@@ -39,23 +39,22 @@ typedef struct command_t
 
 int cmd_account( irc_t *irc, char **cmd );
 int cmd_help( irc_t *irc, char **args);
-int cmd_login( irc_t *irc, char **args);
 int cmd_info( irc_t *irc, char **args);
-int cmd_logout( irc_t *irc, char **args );
 int cmd_add( irc_t *irc, char **args) ;
 int cmd_rename( irc_t *irc, char **args );
 int cmd_remove( irc_t *irc, char **args );
 int cmd_block( irc_t *irc, char **args );
 int cmd_allow( irc_t *irc, char **args );
-//int cmd_register( irc_t *irc, char **args );
 int cmd_save( irc_t *irc, char **args );
 int cmd_set( irc_t *irc, char **args );
 int cmd_yesno( irc_t *irc, char **args );
 int cmd_identify( irc_t *irc, char **args );
 int cmd_register( irc_t *irc, char **args );
+int cmd_drop( irc_t *irc, char **args );
 int cmd_blist( irc_t *irc, char **cmd );
 int cmd_nick( irc_t *irc, char **cmd );
 int cmd_qlist( irc_t *irc, char **cmd );
+int cmd_import_buddies( irc_t *irc, char **cmd );
 
 extern command_t commands[];
 
